@@ -63,5 +63,5 @@ if __name__ == "__main__":
     except KeyboardInterrupt:
         sys.exit()
 
-    except Exception as e:
-        send_message(e)
+    # except Exception as e:
+    #     send_message(e)
